Assert

Struct Assert 

pub struct Assert {
    pub headers: Option<HeaderMap>,
    pub status: Option<StatusCode>,
    pub json: Option<Option<Value>>,
    pub response_time_ms: Option<u64>,
    pub log_settings: LogSettings,
}
Assert uses an internal representation of the http response to assert against. If the HTTP request was successfully sent, then each field will be Some, otherwise None.

Fields

headers: Option<HeaderMap>

The http response header to assert.

status: Option<StatusCode>

The http response status to assert.

json: Option<Option<Value>>

The http response json body to assert.

response_time_ms: Option<u64>

The http response time (in milliseconds) to assert.

log_settings: LogSettings

The test results output.

Implementations

Source

impl Assert

pub async fn new( response: Option<impl Response>, response_time_ms: Option<u64>, log_settings: LogSettings, ) -> Self

Creates an Assert instance with an internal representation of the given response to assert.

pub fn assert_fn<F>(self, func: F) -> Assert
where F: for<'a> Fn(&'a Assert),

Extends the built-in assertions with a custom assertion. The closure gives access to the Assert instance.

Example
Grillon::new("https://jsonplaceholder.typicode.com")?
    .get("/users")
    .assert()
    .await
    .status(is_between(200, 299))
    .assert_fn(|assert| {
        assert!(!assert.headers.is_empty());
        assert!(assert.status == StatusCode::CREATED);
        assert!(assert.json.is_some());

        println!("Json response : {:#?}", assert.json);
     })
     .status(is(StatusCode::CREATED));
pub fn status<T>(self, expr: Expression<T>) -> Assert

Asserts the status of the response.

pub fn json_body<T>(self, expr: Expression<T>) -> Assert
where T: JsonBodyDsl<Value>,

Asserts the json body of the response.

pub fn json_path<T>(self, path: &str, expr: Expression<T>) -> Assert
where T: JsonPathDsl<Value>,

Asserts the value found at the given json path.

pub fn response_time<T>(self, expr: Expression<T>) -> Assert
where T: TimeDsl<u64>,

Asserts the response time (in milliseconds).

pub fn headers<T>(self, expr: Expression<T>) -> Assert

Asserts the headers of the response.

pub fn header<H, T>(self, header_name: H, expr: Expression<T>) -> Assert

Asserts a specific header of the response.