Module traits

Module traits 

This module contains various traits for comparisons, range checks and inner checks.

Traits

Container
A representation of a container of items where we can perform inner checks with has and has_not functions.
Equality
Trait to test the equality between two values.
JsonSchema
Trait to test if a json value matches the json schema.
LessThan
Trait to test if a value is less than the other.
Matching
Trait to test if a json value matches the regex.
RangeInclusive
Trait to test if a value is withing an inclusive range.