LessThan

Trait LessThan 

pub trait LessThan<T: ?Sized> {
    type Assertion;

    // Required method
    fn less_than(&self, other: &T) -> Self::Assertion;
}
Trait to test if a value is less than the other.

Required Associated Types

type Assertion

The resulting assertion after applying the less than test.

Required Methods

fn less_than(&self, other: &T) -> Self::Assertion

Asserts the value is in open range.

Implementations on Foreign Types

Source

impl LessThan<u64> for u64

Source

type Assertion = Assertion<u64>

Source

fn less_than(&self, other: &u64) -> Self::Assertion

Implementors