Request

Struct Request 

pub struct Request<'c> {
    pub method: Method,
    pub url: Url,
    pub headers: Result<HeaderMap>,
    pub payload: Option<Body>,
    pub client: &'c Client,
    pub log_settings: &'c LogSettings,
    pub basic_auth: Option<BasicAuth>,
    pub bearer_auth: Option<BearerToken>,
}
Represents an outgoing http request.

Can be executed with Request::assert().

Fields

method: Method

The http request method.

url: Url

The http request url.

headers: Result<HeaderMap>

The http request headers.

payload: Option<Body>

The http request payload.

client: &'c Client

The client used for this outgoing request.

log_settings: &'c LogSettings

The log settings that will be used to output test results when asserting the http response.

basic_auth: Option<BasicAuth>

Basic authenthication information.

bearer_auth: Option<BearerToken>

Bearer authentication token.

Implementations

Source

impl Request<'_>

pub fn headers<H: RequestHeaders>(self, headers: H) -> Self

Sets the headers to the Request.

Example
Grillon::new("https://jsonplaceholder.typicode.com")?
    .delete("users/1")
    .headers(vec![(
        header::CONTENT_TYPE,
        header::HeaderValue::from_static("application/json"),
    )]);
pub fn payload(self, json: Value) -> Self

Sets the body to the Request.

Example
Grillon::new("https://jsonplaceholder.typicode.com")?
    .post("users")
    .payload(json!({
        "name": "Isaac",
     }));
pub fn basic_auth<U, P>(self, username: U, password: Option<P>) -> Self
where U: AsRef<str> + Display, P: AsRef<str> + Display,

Enable HTTP basic authentication.

Basic authentication will automatically be considered as a sensitive header.

pub fn bearer_auth<T>(self, token: T) -> Self
where T: AsRef<str> + Display,

Enable HTTP bearer authentication.

Bearer authentication will automatically be considered as a sensitive header.

pub async fn assert(self) -> Assert

Sends the http request and creates an instance of Assert with the http response.

This function consumes the Request.

Example
Grillon::new("https://jsonplaceholder.typicode.com")?
    .get("users")
    .assert()
    .await;