pub enum UnprocessableReason {
InvalidJsonPath(String),
MissingJsonBody,
MissingHeader,
InvalidJsonSchema(String, String),
SerializationFailure(String),
InvalidHttpRequestHeaders(String),
InvalidHeaderValue(String),
InvalidRegex(String),
HttpRequestFailure(String),
Other(String),
}Expand description
Unprocessable event reason. This enum should be used when the assertion syntax is correct but the implementor is unable to process the assertion due to an unexpected event.
For example, when an implementation asserts that a word exists in a file but there is no read access. In this case, the assertion fails not because the word is missing, but because the file content cannot be processed.
Variants
InvalidJsonPath(String)
Unprocessable json path with the string representation of the path.
MissingJsonBody
Unprocessable json body because it’s missing.
MissingHeader
Unprocessable header value because the correspond header key is missing.
InvalidJsonSchema(String, String)
Unprocessable json schema.
SerializationFailure(String)
Serialization failure.
InvalidHttpRequestHeaders(String)
Invalid HTTP request headers.
InvalidHeaderValue(String)
Invalid HTTP header value.
InvalidRegex(String)
Invalid regex pattern.
HttpRequestFailure(String)
If the HTTP request results in an error while sending request, redirect loop was detected or redirect limit was exhausted.
Other(String)
Unprocessable entity.