This module contains various traits for comparisons, range checks and inner checks.
Traits
- Container
- A representation of a container of items where we can perform inner checks
with
hasandhas_notfunctions. - Equality
- Trait to test the equality between two values.
- Json
Schema - Trait to test if a json value matches the json schema.
- Less
Than - Trait to test if a value is less than the other.
- Matching
- Trait to test if a json value matches the regex.
- Range
Inclusive - Trait to test if a value is withing an inclusive range.