pub trait LessThan<T: ?Sized> {
type Assertion;
// Required method
fn less_than(&self, other: &T) -> Self::Assertion;
}Expand description
Trait to test if a value is less than the other.
pub trait LessThan<T: ?Sized> {
type Assertion;
// Required method
fn less_than(&self, other: &T) -> Self::Assertion;
}Trait to test if a value is less than the other.